:py:mod:`source_template_worker`
================================

.. py:module:: source_template_worker


Module Contents
---------------


Functions
~~~~~~~~~

.. autoapisummary::

   source_template_worker.initialise
   source_template_worker.work_function
   source_template_worker.on_end_of_life



Attributes
~~~~~~~~~~

.. autoapisummary::

   source_template_worker.current_dir
   source_template_worker.current_dir
   source_template_worker.running
   source_template_worker.global_var_1
   source_template_worker.global_var_2
   source_template_worker.global_var_3
   source_template_worker.global_var_4
   source_template_worker.vis


.. py:data:: current_dir
   

   

.. py:data:: current_dir
   

   

.. py:data:: running
   :annotation: = False

   

.. py:data:: global_var_1
   :annotation: :str

   

.. py:data:: global_var_2
   :annotation: :str

   

.. py:data:: global_var_3
   :annotation: :float

   

.. py:data:: global_var_4
   :annotation: :int

   

.. py:data:: vis
   :annotation: :Heron.gui.visualisation_dpg.VisualisationDPG

   

.. py:function:: initialise(worker_object)


.. py:function:: work_function(worker_object)


.. py:function:: on_end_of_life()


